@@ -1,15 +1,15 @@
-from __future__ import print_function, unicode_literals
+from __future__ import absolute_import, print_function, unicode_literals
 
 from time import time
 
-# 'debugsqlshell' is the same as the 'shell'.
-from django.core.management.commands.shell import Command               # noqa
-from django.db.backends import util
-
 import sqlparse
+from django.core.management.commands.shell import Command  # noqa
+from django.db.backends import utils as db_backends_utils
+
+# 'debugsqlshell' is the same as the 'shell'.
 
 
-class PrintQueryWrapper(util.CursorDebugWrapper):
+class PrintQueryWrapper(db_backends_utils.CursorDebugWrapper):
     def execute(self, sql, params=()):
         start_time = time()
         try:
@@ -19,7 +19,7 @@ class PrintQueryWrapper(util.CursorDebugWrapper):
             end_time = time()
             duration = (end_time - start_time) * 1000
             formatted_sql = sqlparse.format(raw_sql, reindent=True)
-            print('%s [%.2fms]' % (formatted_sql, duration))
+            print("%s [%.2fms]" % (formatted_sql, duration))
 
 
-util.CursorDebugWrapper = PrintQueryWrapper
+db_backends_utils.CursorDebugWrapper = PrintQueryWrapper
