@@ -4,53 +4,61 @@ Debug Toolbar middleware
 
 from __future__ import absolute_import, unicode_literals
 
-try:
-    from importlib import import_module
-except ImportError:  # python 2.6
-    from django.utils.importlib import import_module
 import re
 import threading
 
 from django.conf import settings
+from django.utils import six
+from django.utils.deprecation import MiddlewareMixin
 from django.utils.encoding import force_text
+from django.utils.lru_cache import lru_cache
+from django.utils.module_loading import import_string
 
-from debug_toolbar.toolbar import DebugToolbar
 from debug_toolbar import settings as dt_settings
+from debug_toolbar.toolbar import DebugToolbar
 
-_HTML_TYPES = ('text/html', 'application/xhtml+xml')
-# Handles python threading module bug - http://bugs.python.org/issue14308
-threading._DummyThread._Thread__stop = lambda x: 1
+_HTML_TYPES = ("text/html", "application/xhtml+xml")
 
 
 def show_toolbar(request):
     """
     Default function to determine whether to show the toolbar on a given page.
     """
-    if request.META.get('REMOTE_ADDR', None) not in settings.INTERNAL_IPS:
-        return False
-
-    if request.is_ajax():
+    if request.META.get("REMOTE_ADDR", None) not in settings.INTERNAL_IPS:
         return False
 
     return bool(settings.DEBUG)
 
 
-class DebugToolbarMiddleware(object):
+@lru_cache()
+def get_show_toolbar():
+    # If SHOW_TOOLBAR_CALLBACK is a string, which is the recommended
+    # setup, resolve it to the corresponding callable.
+    func_or_path = dt_settings.get_config()["SHOW_TOOLBAR_CALLBACK"]
+    if isinstance(func_or_path, six.string_types):
+        return import_string(func_or_path)
+    else:
+        return func_or_path
+
+
+class DebugToolbarMiddleware(MiddlewareMixin):
     """
     Middleware to set up Debug Toolbar on incoming request and render toolbar
     on outgoing response.
     """
+
     debug_toolbars = {}
 
     def process_request(self, request):
         # Decide whether the toolbar is active for this request.
-        func_path = dt_settings.CONFIG['SHOW_TOOLBAR_CALLBACK']
-        # Replace this with import_by_path in Django >= 1.6.
-        mod_path, func_name = func_path.rsplit('.', 1)
-        show_toolbar = getattr(import_module(mod_path), func_name)
+        show_toolbar = get_show_toolbar()
         if not show_toolbar(request):
             return
 
+        # Don't render the toolbar during AJAX requests.
+        if request.is_ajax():
+            return
+
         toolbar = DebugToolbar(request)
         self.__class__.debug_toolbars[threading.current_thread().ident] = toolbar
 
@@ -80,7 +88,9 @@ class DebugToolbarMiddleware(object):
         return response
 
     def process_response(self, request, response):
-        toolbar = self.__class__.debug_toolbars.pop(threading.current_thread().ident, None)
+        toolbar = self.__class__.debug_toolbars.pop(
+            threading.current_thread().ident, None
+        )
         if not toolbar:
             return response
 
@@ -97,32 +107,59 @@ class DebugToolbarMiddleware(object):
             panel.disable_instrumentation()
 
         # Check for responses where the toolbar can't be inserted.
-        content_encoding = response.get('Content-Encoding', '')
-        content_type = response.get('Content-Type', '').split(';')[0]
-        if any((getattr(response, 'streaming', False),
-                'gzip' in content_encoding,
-                content_type not in _HTML_TYPES)):
+        content_encoding = response.get("Content-Encoding", "")
+        content_type = response.get("Content-Type", "").split(";")[0]
+        if any(
+            (
+                getattr(response, "streaming", False),
+                "gzip" in content_encoding,
+                content_type not in _HTML_TYPES,
+            )
+        ):
             return response
 
         # Collapse the toolbar by default if SHOW_COLLAPSED is set.
-        if toolbar.config['SHOW_COLLAPSED'] and 'djdt' not in request.COOKIES:
-            response.set_cookie('djdt', 'hide', 864000)
+        if toolbar.config["SHOW_COLLAPSED"] and "djdt" not in request.COOKIES:
+            response.set_cookie("djdt", "hide", 864000)
 
         # Insert the toolbar in the response.
-        content = force_text(response.content, encoding=settings.DEFAULT_CHARSET)
-        insert_before = dt_settings.CONFIG['INSERT_BEFORE']
-        try:                    # Python >= 2.7
-            pattern = re.escape(insert_before)
-            bits = re.split(pattern, content, flags=re.IGNORECASE)
-        except TypeError:       # Python < 2.7
-            pattern = '(.+?)(%s|$)' % re.escape(insert_before)
-            matches = re.findall(pattern, content, flags=re.DOTALL | re.IGNORECASE)
-            bits = [m[0] for m in matches if m[1] == insert_before]
-            # When the body ends with a newline, there's two trailing groups.
-            bits.append(''.join(m[0] for m in matches if m[1] == ''))
+        content = force_text(response.content, encoding=response.charset)
+        insert_before = dt_settings.get_config()["INSERT_BEFORE"]
+        pattern = re.escape(insert_before)
+        bits = re.split(pattern, content, flags=re.IGNORECASE)
         if len(bits) > 1:
+            # When the toolbar will be inserted for sure, generate the stats.
+            for panel in reversed(toolbar.enabled_panels):
+                panel.generate_stats(request, response)
+                panel.generate_server_timing(request, response)
+
+            response = self.generate_server_timing_header(
+                response, toolbar.enabled_panels
+            )
+
             bits[-2] += toolbar.render_toolbar()
             response.content = insert_before.join(bits)
-            if response.get('Content-Length', None):
-                response['Content-Length'] = len(response.content)
+            if response.get("Content-Length", None):
+                response["Content-Length"] = len(response.content)
+        return response
+
+    @staticmethod
+    def generate_server_timing_header(response, panels):
+        data = []
+
+        for panel in panels:
+            stats = panel.get_server_timing_stats()
+            if not stats:
+                continue
+
+            for key, record in stats.items():
+                # example: `SQLPanel_sql_time=0; "SQL 0 queries"`
+                data.append(
+                    '{}_{}={}; "{}"'.format(
+                        panel.panel_id, key, record.get("value"), record.get("title")
+                    )
+                )
+
+        if data:
+            response["Server-Timing"] = ", ".join(data)
         return response
