@@ -45,16 +45,22 @@ class SignalsPanel(Panel):
         # here we have to handle a double count translation, hence the
         # hard coding of one signal
         if num_signals == 1:
-            return ungettext(
-                "%(num_receivers)d receiver of 1 signal",
-                "%(num_receivers)d receivers of 1 signal",
+            return (
+                ungettext(
+                    "%(num_receivers)d receiver of 1 signal",
+                    "%(num_receivers)d receivers of 1 signal",
+                    num_receivers,
+                )
+                % {"num_receivers": num_receivers}
+            )
+        return (
+            ungettext(
+                "%(num_receivers)d receiver of %(num_signals)d signals",
+                "%(num_receivers)d receivers of %(num_signals)d signals",
                 num_receivers,
-            ) % {"num_receivers": num_receivers}
-        return ungettext(
-            "%(num_receivers)d receiver of %(num_signals)d signals",
-            "%(num_receivers)d receivers of %(num_signals)d signals",
-            num_receivers,
-        ) % {"num_receivers": num_receivers, "num_signals": num_signals}
+            )
+            % {"num_receivers": num_receivers, "num_signals": num_signals}
+        )
 
     title = _("Signals")
 
